%global common_description %{expand:
Granite is a companion library for GTK+ and GLib. Among other things, it
provides complex widgets and convenience functions designed for use in
apps built for elementary.}

%{!?_vpath_srcdir:%global _vpath_srcdir .}
%{!?_vpath_builddir:%global _vpath_builddir %{_target_platform}}
%{!?__global_cflags:%global __global_cflags  %{optflags}}
%{!?__global_cxxflags:%global __global_cxxflags  %{optflags}}
%{!?__global_fflags:%global __global_fflags  %{optflags} -I%_fmoddir}
%{!?__global_fcflags:%global __global_fcflags %{optflags} -I%_fmoddir}
%{!?__global_ldflags:%global __global_ldflags -Wl,-z,relro %{_hardened_ldflags}}
%{!?__meson_wrap_mod:%global __meson_wrap_mode default}

Name:           granite
Version:        5.2.2
Release:        2.1%{?dist}
License:        LGPLv3+
Group:          Development/Libraries
URL:            https://github.com/elementary/%{name}
Summary:        elementary companion library for GTK+ and GLib
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# ported to meson, patch already accepted upstream
# https://github.com/elementary/granite/commit/2066b37
Patch0:         00-meson-port.patch

# small meson regression fix from upstream
# https://github.com/elementary/granite/commit/f1b29f5
Patch1:         01-meson-pkgconfig-requires-fix.patch

# move required "clock-format" gsettings key from wingpanel-indicator-datetime:
# this is a temporary fix - especially for third-party applications - until
# this issue can be resolved better upstream
Patch2:         02-datetime-clock-format-gsettings.patch

BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  vala >= 0.40

%if 0%{?rhel} && 0%{?rhel} < 8
BuildRequires:  python34-devel
BuildRequires:  python36-devel
%else
BuildRequires:  python3-devel
%endif

BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gobject-introspection-1.0)

# granite provides and needs some generic icons
Requires:       hicolor-icon-theme


%description %{common_description}


%package        devel
Summary:        Granite Toolkit development headers
Requires:       %{name}%{?_isa} = %{version}-%{release}
%description    devel %{common_description}

This package contains the development headers.


%prep
%autosetup -p1


%build
%meson
%meson_build


%install
%meson_install

%find_lang granite


%check
desktop-file-validate \
    "%{buildroot}/%{_datadir}/applications/granite-demo.desktop"


%post   -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files -f granite.lang
%doc AUTHORS CODE_OF_CONDUCT.md README.md
%license COPYING

%{_libdir}/libgranite.so.5
%{_libdir}/libgranite.so.5.*

%{_libdir}/girepository-1.0/Granite-1.0.typelib

%{_datadir}/glib-2.0/schemas/io.elementary.granite.gschema.xml

%{_datadir}/icons/hicolor/*/actions/appointment.svg
%{_datadir}/icons/hicolor/*/actions/open-menu.svg
%{_datadir}/icons/hicolor/scalable/actions/open-menu-symbolic.svg


%files devel
%doc AUTHORS CODE_OF_CONDUCT.md README.md
%license COPYING

%{_bindir}/granite-demo

%{_libdir}/libgranite.so
%{_libdir}/pkgconfig/granite.pc

%{_includedir}/granite/

%{_datadir}/applications/granite-demo.desktop
%{_datadir}/gir-1.0/Granite-1.0.gir
%{_datadir}/vala/vapi/granite.deps
%{_datadir}/vala/vapi/granite.vapi


%changelog
* Sat Feb 09 2019 Tomasz Tomasik <scx.mail@gmail.com> - 5.2.2-2.1
- Rebuilt for EL7

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Dec 17 2018 Fabio Valentini <decathorpe@gmail.com> - 5.2.2-1
- Update to version 5.2.2.
- Add patch to fix a meson regression with the pkgconfig file.

* Sun Dec 16 2018 Fabio Valentini <decathorpe@gmail.com> - 5.2.1-1
- Update to version 5.2.1.
- Port to meson.
- Resolve circular dependencies within Pantheon and fix third-party applications.

* Mon Aug 27 2018 Fabio Valentini <decathorpe@gmail.com> - 5.1.0-1
- Update to version 5.1.0.

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Jun 09 2018 Fabio Valentini <decathorpe@gmail.com> - 5.0-1
- Update to version 5.0.

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Jan 06 2018 Fabio Valentini <decathorpe@gmail.com> - 0.5-2
- Remove icon cache scriptlets, replaced by file triggers.

* Fri Nov 03 2017 Fabio Valentini <decathorpe@gmail.com> - 0.5-1
- Update to version 0.5.

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun May 07 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.1-1
- Update to version 0.4.1.

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.0.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 24 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-8
- Make BR on /usr/bin/pkg-config explicit.

* Sun Nov 27 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-7
- Check granite-demo.desktop file explicitly.
- Correct license (s/LGPLv3/LGPLv3+).

* Sun Nov 27 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-6
- Add missing Requires to -devel.

* Thu Nov 24 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-5
- Spec file cosmetics.

* Thu Sep 29 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-4
- Mass rebuild.

* Wed Sep 28 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-3
- Spec file cleanups.

* Mon Sep 19 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-2
- Spec file cosmetics.

* Tue Aug 09 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-1
- Update to version 0.4.0.1.

* Sat Jun 18 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4-1
- Update to version 0.4.


